@@ -12,19 +12,19 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from qubell.api.private import application
 
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.1"
+__version__ = "1.0.5"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
 import requests
 import simplejson as json
-from qubell.api.tools import retry
 
+from qubell.api.tools import retry
+from qubell.api.private import application
 
 
 class Instance(application.Application):
@@ -92,7 +92,7 @@ class Instance(application.Application):
 
 
     def ready(self, timeout=3):  # Shortcut for convinience. Temeout = 3 min (ask timeout*6 times every 10 sec)
-        return self.waitForStatus(final='Running', accepted=['Requested', 'Executing', 'Unknown'], timeout=[timeout*6, 10, 1])
+        return self.waitForStatus(final='Running', accepted=['Launching', 'Requested', 'Executing', 'Unknown'], timeout=[timeout*6, 10, 1])
         # TODO: Unknown status  should be removed
 
         #TODO: not available
