@@ -16,15 +16,14 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.1"
+__version__ = "1.0.5"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
 
 import requests
 
-import application
-from qubell.api.private import exceptions
+from qubell.api.private import application, exceptions
 
 
 class Revision(application.Application):
