@@ -12,13 +12,10 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from qubell.api.public import instance, revision
-
-
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.1"
+__version__ = "1.0.5"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -52,6 +49,8 @@ class Application(Organization):
         raise NotImplementedError
 
     def clean(self):
+        from qubell.api.public import instance, revision
+
         instances = self.instances
         if instances:
             for ins in instances:
@@ -111,8 +110,7 @@ class Application(Organization):
         log.debug('RESPONSE: %s' % resp.text)
         if resp.status_code == 200:
             instance_id = resp.json()['id']
-            from qubell.api.public.instance import Instance
-            return Instance(context=self.context, id=instance_id)
+            return self.get_instance(id=instance_id)
         raise exceptions.ApiError('Unable to launch application id: %s, got error: %s' % (self.applicationId, resp.text))
 
     def get_instance(self, id):
