@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.1"
+__version__ = "1.0.5"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -24,8 +24,7 @@ import logging as log
 import requests
 import simplejson as json
 
-import application
-from qubell.api.private import exceptions
+from qubell.api.public import application, exceptions
 from qubell.api.tools import retry
 
 
@@ -60,7 +59,7 @@ class Instance(application.Application):
         resp = self.json()
         if not resp.has_key(key):
             raise exceptions.NotFoundError('Cannot get property %s' % key)
-        return resp[key] or False
+        return resp[key]
 
 
     def waitForStatus(self, final='Running', accepted=['Requested'], timeout=[20, 10, 1]):
@@ -94,7 +93,7 @@ class Instance(application.Application):
 
 
     def ready(self, timeout=3):  # Shortcut for convinience. Temeout = 3 min (ask timeout*6 times every 10 sec)
-        return self.waitForStatus(final='Running', accepted=['Requested', 'Executing', 'Unknown'], timeout=[timeout*6, 10, 1])
+        return self.waitForStatus(final='Running', accepted=['Launching', 'Requested', 'Executing', 'Unknown'], timeout=[timeout*6, 10, 1])
         # TODO: Unknown status  should be removed
 
         #TODO: not available
